package com.jjt.biz.service;

import com.jjt.biz.domain.TwinDevice;

import java.util.List;
import java.util.Map;

/**
 * 设备管理Service接口
 *
 * @author wukai
 * @date 2025-01-15
 */
public interface ITwinDeviceService {
    /**
     * 查询设备管理
     *
     * @param deviceId 设备管理主键
     * @return 设备管理
     */
    public TwinDevice selectTwinDeviceByDeviceId(Long deviceId);

    /**
     * 查询设备管理列表
     *
     * @param twinDevice 设备管理
     * @return 设备管理集合
     */
    public List<TwinDevice> selectTwinDeviceList(TwinDevice twinDevice);

    /**
     * 新增设备管理
     *
     * @param twinDevice 设备管理
     * @return 结果
     */
    public int insertTwinDevice(TwinDevice twinDevice);

    /**
     * 修改设备管理
     *
     * @param twinDevice 设备管理
     * @return 结果
     */
    public int updateTwinDevice(TwinDevice twinDevice);

    /**
     * 批量删除设备管理
     *
     * @param deviceIds 需要删除的设备管理主键集合
     * @return 结果
     */
    public int deleteTwinDeviceByDeviceIds(Long[] deviceIds);

    /**
     * 删除设备管理信息
     *
     * @param deviceId 设备管理主键
     * @return 结果
     */
    public int deleteTwinDeviceByDeviceId(Long deviceId);

    /**
     * 通过设备编号查询设备
     *
     * @param code 设备编号
     * @return 设备信息
     */
    TwinDevice selectTwinDeviceByCode(String code);

    /**
     * 获取deviceMap
     *
     * @return map
     */
    Map<Long, TwinDevice> deviceMap();
}
